@@ -3,7 +3,7 @@ use v5.24;
 use warnings;
 use experimental qw< signatures >;
 no warnings qw< experimental::signatures >;
-{ our $VERSION = '0.001' }
+{ our $VERSION = '0.002' }
 
 use Exporter 'import';
 our @EXPORT_OK = qw< d run >;
@@ -374,7 +374,10 @@ sub print_help ($self, $target) {
    my $options = $command->{options} // [];
    if ($options->@*) {
       print {$fh} "Options:\n";
+      my $n = 0; # count the option
       for my $option ($options->@*) {
+         print {$fh} "\n" if $n++;
+
          printf {$fh} "%15s: %s\n", name_for_option($option),
            $option->{help} // '';
 
